@@ -1,16 +1,9 @@
-package WWW::NOS::Open;    # -*- cperl; cperl-indent-level: 4 -*-
+package WWW::NOS::Open 0.100;    # -*- cperl; cperl-indent-level: 4 -*-
 use strict;
 use warnings;
 
-# $Id: Open.pm 414 2011-01-13 22:43:18Z roland $
-# $Revision: 414 $
-# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/candi/trunk/WWW-NOS-Open/lib/WWW/NOS/Open.pm $
-# $Date: 2011-01-13 23:43:18 +0100 (Thu, 13 Jan 2011) $
-
 use utf8;
-use 5.006000;
-
-our $VERSION = '0.02';
+use 5.014000;
 
 use Date::Calc qw(Add_Delta_Days Date_to_Days Delta_Days Today);
 use Date::Format;
@@ -27,7 +20,7 @@ use URI::Escape qw(uri_escape);
 use URI;
 use XML::Simple;
 
-use namespace::autoclean -also => qr/^__/sxm;
+use namespace::autoclean '-also' => qr/^__/sxm;
 
 use WWW::NOS::Open::Article;
 use WWW::NOS::Open::AudioFragment;
@@ -41,14 +34,14 @@ use WWW::NOS::Open::Version;
 use WWW::NOS::Open::Video;
 
 use Readonly;
-Readonly::Scalar my $SERVER => $ENV{NOSOPEN_SERVER} || q{http://open.nos.nl};
-Readonly::Scalar my $TIMEOUT       => 15;
-Readonly::Scalar my $AGENT         => q{WWW::NOS::Open/} . $VERSION;
-Readonly::Scalar my $DATE_FORMAT   => q{%04u-%02u-%02u};
-Readonly::Scalar my $DEFAULT_START => -1;                            # Yesterday
-Readonly::Scalar my $DEFAULT_END   => 1;                             # Tomorrow
-Readonly::Scalar my $MAX_RANGE     => 14;                            # Two weeks
-Readonly::Scalar my $GET           => q{GET};
+Readonly::Scalar my $SERVER => $ENV{'NOSOPEN_SERVER'} || q{http://open.nos.nl};
+Readonly::Scalar my $TIMEOUT => 15;
+Readonly::Scalar my $AGENT   => q{WWW::NOS::Open/} . $WWW::NOS::Open::VERSION;
+Readonly::Scalar my $DATE_FORMAT      => q{%04u-%02u-%02u};
+Readonly::Scalar my $DEFAULT_START    => -1;                  # Yesterday
+Readonly::Scalar my $DEFAULT_END      => 1;                   # Tomorrow
+Readonly::Scalar my $MAX_RANGE        => 14;                  # Two weeks
+Readonly::Scalar my $GET              => q{GET};
 Readonly::Scalar my $DEFAULT_API_KEY  => q{TEST};
 Readonly::Scalar my $DEFAULT_OUTPUT   => q{xml};
 Readonly::Scalar my $DEFAULT_CATEGORY => q{nieuws};
@@ -65,13 +58,13 @@ Readonly::Scalar my $XML_DETECT    => qr{^<}smx;
 Readonly::Scalar my $STRIP_PRIVATE => qr{^_}smx;
 
 Readonly::Hash my %ERR => (
-    INTERNAL_SERVER => q{Internal server error or no response recieved},
-    UNPARSABLE      => q{Could not parse data},
-    EXCEEDED_RANGE  => qq{Date range exceeds maximum of $MAX_RANGE days},
+    'INTERNAL_SERVER' => q{Internal server error or no response recieved},
+    'UNPARSABLE'      => q{Could not parse data},
+    'EXCEEDED_RANGE'  => qq{Date range exceeds maximum of $MAX_RANGE days},
 );
 Readonly::Hash my %LOG => (
-    REQUESTING    => q{Requesting %s},
-    RESPONSE_CODE => q{Response code %d},
+    'REQUESTING'    => q{Requesting %s},
+    'RESPONSE_CODE' => q{Response code %d},
 );
 
 Log::Log4perl::easy_init($ERROR);
@@ -79,19 +72,19 @@ Log::Log4perl::easy_init($ERROR);
 my $log = Log::Log4perl->get_logger(__PACKAGE__);
 
 has '_ua' => (
-    is      => 'ro',
-    isa     => 'LWP::UserAgent',
-    default => sub {
+    'is'      => 'ro',
+    'isa'     => 'LWP::UserAgent',
+    'default' => sub {
         LWP::UserAgent->new(
-            timeout => $TIMEOUT,
-            agent   => $AGENT,
+            'timeout' => $TIMEOUT,
+            'agent'   => $AGENT,
         );
     },
 );
 
 has '_version' => (
-    is  => 'ro',
-    isa => 'WWW::NOS::Open::Version',
+    'is'  => 'ro',
+    'isa' => 'WWW::NOS::Open::Version',
 );
 
 sub get_version {
@@ -108,31 +101,31 @@ sub _parse_version {
     my ( $self, $body ) = @_;
     my ( $version, $build );
     if ( $body =~ /$XML_DETECT/gsmx ) {
-        my $xml = XML::Simple->new( ForceArray => 1 )->XMLin($body);
-        $version = $xml->{item}[0]->{version}[0];
-        $build   = $xml->{item}[0]->{build}[0];
+        my $xml = XML::Simple->new( 'ForceArray' => 1 )->XMLin($body);
+        $version = $xml->{'item'}[0]->{'version'}[0];
+        $build   = $xml->{'item'}[0]->{'build'}[0];
     }
     else {
-        $log->fatal( $ERR{UNPARSABLE} );
+        $log->fatal( $ERR{'UNPARSABLE'} );
     }
     return WWW::NOS::Open::Version->new( $version, $build );
 }
 
 has '_default_output' => (
-    is       => 'ro',
-    isa      => 'Str',
-    default  => $DEFAULT_OUTPUT,
-    reader   => '_get_default_output',
-    init_arg => 'default_output',
+    'is'       => 'ro',
+    'isa'      => 'Str',
+    'default'  => $DEFAULT_OUTPUT,
+    'reader'   => '_get_default_output',
+    'init_arg' => 'default_output',
 );
 
 has '_api_key' => (
-    is       => 'rw',
-    isa      => 'Str',
-    default  => $DEFAULT_API_KEY,
-    reader   => 'get_api_key',
-    writer   => 'set_api_key',
-    init_arg => 'api_key',
+    'is'       => 'rw',
+    'isa'      => 'Str',
+    'default'  => $DEFAULT_API_KEY,
+    'reader'   => 'get_api_key',
+    'writer'   => 'set_api_key',
+    'init_arg' => 'api_key',
 );
 
 sub _get_latest_resources {
@@ -167,11 +160,11 @@ sub __get_props {
 sub _parse_resource {
     my ( $self, $type, $hr_resource ) = @_;
     my %mapping = (
-        article   => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type,
-        video     => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type,
-        audio     => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type . $FRAGMENT,
-        document  => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type,
-        broadcast => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type,
+        'article'   => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type,
+        'video'     => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type,
+        'audio'     => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type . $FRAGMENT,
+        'document'  => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type,
+        'broadcast' => __PACKAGE__ . $DOUBLE_COLON . ucfirst $type,
     );
 
     my @props = __get_props( ( $mapping{$type} )->meta );
@@ -182,7 +175,7 @@ sub _parse_resource {
           ? %{ $hr_resource->{$prop}[0] }
           : $hr_resource->{$prop}[0];
     }
-    $param{keywords} = $hr_resource->{keywords}->[0]->{keyword} || [];
+    $param{'keywords'} = $hr_resource->{'keywords'}->[0]->{'keyword'} || [];
     if ( my $resource = ( $mapping{$type} )->new(%param) ) {
         return $resource;
     }
@@ -194,7 +187,7 @@ sub _parse_resources {
     my @resources;
 
     if ( $body =~ /$XML_DETECT/gsmx ) {
-        my $xml = XML::Simple->new( ForceArray => 1 )->XMLin($body);
+        my $xml = XML::Simple->new( 'ForceArray' => 1 )->XMLin($body);
         my @xml_resources = @{ $xml->{$type} };
         while ( my $resource = shift @xml_resources ) {
             push @resources, $self->_parse_resource( $type, $resource );
@@ -202,7 +195,7 @@ sub _parse_resources {
         return @resources;
     }
     else {
-        $log->fatal( $ERR{UNPARSABLE} );
+        $log->fatal( $ERR{'UNPARSABLE'} );
     }
     return ();
 }
@@ -221,20 +214,20 @@ sub _parse_result {
     my ( $self, $body ) = @_;
     my @documents;
     if ( $body =~ /$XML_DETECT/gsmx ) {
-        my $xml = XML::Simple->new( ForceArray => 1 )->XMLin($body);
-        my @xml_documents = @{ $xml->{documents}->[0]->{document} };
+        my $xml = XML::Simple->new( 'ForceArray' => 1 )->XMLin($body);
+        my @xml_documents = @{ $xml->{'documents'}->[0]->{'document'} };
         while ( my $hr_document = shift @xml_documents ) {
             push @documents,
               $self->_parse_resource( q{document}, $hr_document );
         }
         my $result = WWW::NOS::Open::Result->new(
-            documents => [@documents],
-            related   => $xml->{related}->[0]->{related},
+            'documents' => [@documents],
+            'related'   => $xml->{'related'}->[0]->{'related'},
         );
         return $result;
     }
     else {
-        $log->fatal( $ERR{UNPARSABLE} );
+        $log->fatal( $ERR{'UNPARSABLE'} );
     }
     return ();
 }
@@ -257,12 +250,12 @@ sub __get_date {
     return (
         (
             sprintf $DATE_FORMAT,
-            Add_Delta_Days( 1, 1, 1, $today + $start_day - 1 )
+            Add_Delta_Days( 1, 1, 1, $today + $start_day - 1 ),
         ),
         (
             sprintf $DATE_FORMAT,
-            Add_Delta_Days( 1, 1, 1, $today + $end_day - 1 )
-        )
+            Add_Delta_Days( 1, 1, 1, $today + $end_day - 1 ),
+        ),
     );
 }
 
@@ -281,10 +274,10 @@ sub _parse_dayguide {
           )
           : $hr_dayguide->{$prop};
     }
-    $param{broadcasts} = [];
-    my @broadcasts = $hr_dayguide->{item};
+    $param{'broadcasts'} = [];
+    my @broadcasts = $hr_dayguide->{'item'};
     while ( my $ar_broadcast = shift @broadcasts ) {
-        push @{ $param{broadcasts} },
+        push @{ $param{'broadcasts'} },
           $self->_parse_resource( q{broadcast}, $ar_broadcast->[0] );
     }
     if ( my $dayguide = WWW::NOS::Open::DayGuide->new(%param) ) {
@@ -297,15 +290,15 @@ sub _parse_guide {
     my ( $self, $body ) = @_;
     my @dayguides;
     if ( $body =~ /$XML_DETECT/gsmx ) {
-        my $xml = XML::Simple->new( ForceArray => 1 )->XMLin($body);
-        my @xml_dayguides = @{ $xml->{dayguide} };
+        my $xml = XML::Simple->new( 'ForceArray' => 1 )->XMLin($body);
+        my @xml_dayguides = @{ $xml->{'dayguide'} };
         while ( my $hr_dayguide = shift @xml_dayguides ) {
             push @dayguides, $self->_parse_dayguide($hr_dayguide);
         }
         return @dayguides;
     }
     else {
-        $log->fatal( $ERR{UNPARSABLE} );
+        $log->fatal( $ERR{'UNPARSABLE'} );
     }
     return ();
 }
@@ -325,7 +318,7 @@ sub _get_broadcasts {
         ## no critic qw(RequireExplicitInclusion)
         NOSOpenExceededRangeException->throw(
             ## use critic
-            error => $ERR{EXCEEDED_RANGE}
+            'error' => $ERR{'EXCEEDED_RANGE'},
         );
     }
     my $url = sprintf $GUIDE_PATH,
@@ -356,14 +349,14 @@ sub _do_request {
         $GET => $url,
         HTTP::Headers->new(),
     );
-    $log->debug( sprintf $LOG{REQUESTING}, $url );
+    $log->debug( sprintf $LOG{'REQUESTING'}, $url );
     my $response = $self->_ua->request($request);
-    $log->debug( sprintf $LOG{RESPONSE_CODE}, $response->code );
+    $log->debug( sprintf $LOG{'RESPONSE_CODE'}, $response->code );
     if ( $response->code == HTTP_INTERNAL_SERVER_ERROR ) {
         ## no critic qw(RequireExplicitInclusion)
         NOSOpenInternalServerErrorException->throw(
             ## use critic
-            error => $ERR{INTERNAL_SERVER}
+            'error' => $ERR{'INTERNAL_SERVER'},
         );
     }
     elsif ( $response->code > HTTP_OK ) {
@@ -372,35 +365,39 @@ sub _do_request {
             ## no critic qw(RequireExplicitInclusion)
             NOSOpenBadRequestException->throw(
                 ## use critic
-                error => $json->decode( $response->decoded_content )
+                'error' => $json->decode( $response->decoded_content ),
             );
         }
         elsif ( $response->code == HTTP_UNAUTHORIZED ) {
             ## no critic qw(RequireExplicitInclusion)
             NOSOpenUnauthorizedException->throw(
                 ## use critic
-                error => $json->decode( $response->decoded_content )
+                'error' => $json->decode(
+                    $response->decoded_content || $response->content,
+                ),
             );
         }
         elsif ( $response->code == HTTP_FORBIDDEN ) {
             ## no critic qw(RequireExplicitInclusion)
             NOSOpenForbiddenException->throw(
                 ## use critic
-                error => $json->decode( $response->decoded_content )
+                'error' => $json->decode(
+                    $response->decoded_content || $response->content,
+                ),
             );
         }
     }
     return $response;
 }
 
-around BUILDARGS => sub {
+around 'BUILDARGS' => sub {
     my $orig  = shift;
     my $class = shift;
     my ( $api_key, $default_output ) = @_;
 
     return $class->$orig(
-        api_key        => $api_key        || $DEFAULT_API_KEY,
-        default_output => $default_output || $DEFAULT_OUTPUT,
+        'api_key'        => $api_key        || $DEFAULT_API_KEY,
+        'default_output' => $default_output || $DEFAULT_OUTPUT,
     );
 };
 
@@ -418,17 +415,13 @@ __END__
 
 =encoding utf8
 
-=for stopwords Roland van Ipenburg API NOS Readonly PHP JSON URI 
-searchengine useragent DateTime XML
-
 =head1 NAME
 
-WWW::NOS::Open - Perl framework for the
-L<Open NOS|http://open.nos.nl/> REST API.
+WWW::NOS::Open - Perl framework for the Open NOS REST API.
 
 =head1 VERSION
 
-This document describes WWW::NOS::Open version 0.02.
+This document describes WWW::NOS::Open version 0.100.
 
 =head1 SYNOPSIS
 
@@ -438,7 +431,9 @@ This document describes WWW::NOS::Open version 0.02.
 
 =head1 DESCRIPTION
 
-Wrapper around the REST API to get data from Open NOS into Perl.
+The L<Dutch public broadcasting foundation NOS|http:://www.nos.nl> provides a
+REST API to their content. This module provides a wrapper around that API to
+use data from the Open NOS platform with Perl.
 
 =head1 SUBROUTINES/METHODS
 
@@ -450,7 +445,7 @@ Create a new WWW::NOS::Open object.
 
 =item 1. The API key to use in the connection to the Open NOS service. You
 need to L<register at Open NOS|http://open.nos.nl/registratie/> to get an API
-key.
+key, and link your IP address to that account to do authorized requests.
 
 =back
 
@@ -497,7 +492,7 @@ C<sport>.  Defaults to the category C<nieuws>.
 
 =head2 C<search>
 
-Search the searchengine from L<NOS|http://www.nos.nl> for keywords. Returns
+Search the search engine from L<NOS|http://www.nos.nl> for keywords. Returns
 a L<WWW::NOS::Open::Results|WWW::NOS::Open::Results> object with a maximum of
 25 items.
 
@@ -546,46 +541,100 @@ object.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-This module uses the environment variable C<NOSOPEN_SERVER> to specify a
-server that is not the default Open NOS live server at
+To use this module with the live content of Open NOS you need an API key which
+can be obtained by registering at L<Open NOS|http://open.nos.nl/registratie/>
+and then configure your account there with the IP range you'll be accessing
+the service from.
+
+This module can use the optional environment variable C<NOSOPEN_SERVER> to
+specify a server URL that is not the default Open NOS live service at
 L<http://open.nos.nl|http://open.nos.nl>.
 
-The useragent identifier used in the request to the REST API is
-C<WWW::NOS::Open/0.01>.
+The user agent identifier used in the request to the REST API is
+C<WWW::NOS::Open/0.100>.
 
 =head1 DEPENDENCIES
 
-L<Date::Calc|Date::Calc>
-L<Date::Format|Date::Format>
-L<HTTP::Headers|HTTP::Headers>
-L<HTTP::Request|HTTP::Request>
-L<HTTP::Status|HTTP::Status>
-L<JSON|JSON>
-L<LWP::UserAgent|LWP::UserAgent>
-L<Log::Log4perl|Log::Log4perl>
-L<Moose|Moose>
-L<Moose::Util::TypeConstraints|Moose::Util::TypeConstraints>
-L<Readonly|Readonly>
-L<URI|URI>
-L<URI::Escape|URI::Escape>
-L<WWW::NOS::Open::Article|WWW::NOS::Open::Article>
-L<WWW::NOS::Open::AudioFragment|WWW::NOS::Open::AudioFragment>
-L<WWW::NOS::Open::Broadcast|WWW::NOS::Open::Broadcast>
-L<WWW::NOS::Open::DayGuide|WWW::NOS::Open::DayGuide>
-L<WWW::NOS::Open::Document|WWW::NOS::Open::Document>
-L<WWW::NOS::Open::Exceptions|WWW::NOS::Open::Exceptions>
-L<WWW::NOS::Open::Result|WWW::NOS::Open::Result>
-L<WWW::NOS::Open::TypeDef|WWW::NOS::Open::TypeDef>
-L<WWW::NOS::Open::Version|WWW::NOS::Open::Version>
-L<WWW::NOS::Open::Video|WWW::NOS::Open::Video>
-L<XML::Simple|XML::Simple>
-L<namespace::autoclean|namespace::autoclean>
+=over
+
+=item * perl 5.14
+
+=item * L<Date::Calc|Date::Calc>
+
+=item * L<Date::Format|Date::Format>
+
+=item * L<HTTP::Headers|HTTP::Headers>
+
+=item * L<HTTP::Request|HTTP::Request>
+
+=item * L<HTTP::Status|HTTP::Status>
+
+=item * L<JSON|JSON>
+
+=item * L<LWP::UserAgent|LWP::UserAgent>
+
+=item * L<Log::Log4perl|Log::Log4perl>
+
+=item * L<Moose|Moose>
+
+=item * L<Moose::Util::TypeConstraints|Moose::Util::TypeConstraints>
+
+=item * L<Readonly|Readonly>
+
+=item * L<URI|URI>, L<URI::Escape|URI::Escape>
+
+=item * L<WWW::NOS::Open::Article|WWW::NOS::Open::Article>
+
+=item * L<WWW::NOS::Open::AudioFragment|WWW::NOS::Open::AudioFragment>
+
+=item * L<WWW::NOS::Open::Broadcast|WWW::NOS::Open::Broadcast>
+
+=item * L<WWW::NOS::Open::DayGuide|WWW::NOS::Open::DayGuide>
+
+=item * L<WWW::NOS::Open::Document|WWW::NOS::Open::Document>
+
+=item * L<WWW::NOS::Open::Exceptions|WWW::NOS::Open::Exceptions>
+
+=item * L<WWW::NOS::Open::Result|WWW::NOS::Open::Result>
+
+=item * L<WWW::NOS::Open::TypeDef|WWW::NOS::Open::TypeDef>
+
+=item * L<WWW::NOS::Open::Version|WWW::NOS::Open::Version>
+
+=item * L<WWW::NOS::Open::Video|WWW::NOS::Open::Video>
+
+=item * L<XML::Simple|XML::Simple>
+
+=item * L<namespace::autoclean|namespace::autoclean>
+
+=back
 
 =head1 INCOMPATIBILITIES
 
+None.
+
 =head1 DIAGNOSTICS
 
-This module uses Log::Log4perl.
+Exceptions in the form of an L<Exception::Class|Exception::Class> are thrown
+when the Open NOS service reports an exception:
+
+=head2 C<NOSOpenUnauthorizedException>
+
+When a request was made without a valid API key, or from an IP address not
+configured to be valid for that API key.
+
+=head2 C<NOSOpenExceededRangeException>
+
+When the time period for a guide request exceeds the supported range of 14
+days.
+
+=head2 C<NOSOpenInternalServerErrorException>
+
+When an internal server error has occurred in the Open NOS service.
+
+=head2 C<NOSOpenBadRequestException>
+
+When the Open NOS service reports the request had bad syntax.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -599,14 +648,14 @@ L<RT for rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-NOS-Open>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg  C<< <ipenburg@xs4all.nl> >>
+Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 by Roland van Ipenburg
+Copyright 2012 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.12.2 or,
+it under the same terms as Perl itself, either Perl version 5.14.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 =head1 DISCLAIMER OF WARRANTY
