@@ -1,20 +1,13 @@
-package WWW::NOS::Open::Broadcast;    # -*- cperl; cperl-indent-level: 4 -*-
+package WWW::NOS::Open::Broadcast 0.100;  # -*- cperl; cperl-indent-level: 4 -*-
 use strict;
 use warnings;
 
-# $Id: Broadcast.pm 414 2011-01-13 22:43:18Z roland $
-# $Revision: 414 $
-# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/candi/trunk/WWW-NOS-Open/lib/WWW/NOS/Open/Broadcast.pm $
-# $Date: 2011-01-13 23:43:18 +0100 (Thu, 13 Jan 2011) $
-
 use utf8;
-use 5.006000;
-
-our $VERSION = '0.02';
+use 5.014000;
 
 use Moose qw/around has with/;
 use Moose::Util::TypeConstraints qw/enum/;
-use namespace::autoclean -also => qr/^__/sxm;
+use namespace::autoclean '-also' => qr/^__/sxm;
 
 use WWW::NOS::Open::TypeDef qw(NOSDateTime NOSURI);
 
@@ -25,47 +18,47 @@ Readonly::Array my @TV_CHANNEL_CODES    => qw(NL1 NL2 NL3);
 Readonly::Array my @RADIO_CHANNEL_CODES => qw(RA1 RA2 RA3 RA4 RA5 RA6);
 
 has '_id' => (
-    is       => 'ro',
-    isa      => 'Int',
-    reader   => 'get_id',
-    init_arg => 'id',
+    'is'       => 'ro',
+    'isa'      => 'Int',
+    'reader'   => 'get_id',
+    'init_arg' => 'id',
 );
 
 has '_channel_icon' => (
-    is       => 'ro',
-    isa      => NOSURI,
-    coerce   => 1,
-    reader   => 'get_channel_icon',
-    init_arg => 'channel_icon',
+    'is'       => 'ro',
+    'isa'      => NOSURI,
+    'coerce'   => 1,
+    'reader'   => 'get_channel_icon',
+    'init_arg' => 'channel_icon',
 );
 
 my @dates = qw(starttime endtime);
 while ( my $date = shift @dates ) {
     has $UNDER
       . $date => (
-        is       => 'ro',
-        isa      => NOSDateTime,
-        coerce   => 1,
-        reader   => $GETTER . $UNDER . $date,
-        init_arg => $date,
+        'is'       => 'ro',
+        'isa'      => NOSDateTime,
+        'coerce'   => 1,
+        'reader'   => $GETTER . $UNDER . $date,
+        'init_arg' => $date,
       );
 }
 
 has '_channel_code' => (
-    is       => 'ro',
-    isa      => enum( [ @TV_CHANNEL_CODES, @RADIO_CHANNEL_CODES ] ),
-    reader   => 'get_channel_code',
-    init_arg => 'channel_code',
+    'is'       => 'ro',
+    'isa'      => enum( [ @TV_CHANNEL_CODES, @RADIO_CHANNEL_CODES ] ),
+    'reader'   => 'get_channel_code',
+    'init_arg' => 'channel_code',
 );
 
 my @strings = qw(type channel_name genre title description);
 while ( my $string = shift @strings ) {
     has $UNDER
       . $string => (
-        is       => 'ro',
-        isa      => 'Str',
-        reader   => $GETTER . $UNDER . $string,
-        init_arg => $string,
+        'is'       => 'ro',
+        'isa'      => 'Str',
+        'reader'   => $GETTER . $UNDER . $string,
+        'init_arg' => $string,
       );
 }
 
@@ -81,16 +74,13 @@ __END__
 
 =encoding utf8
 
-=for stopwords Roland van Ipenburg API NOS DateTime URI URL HTML
-
 =head1 NAME
 
-WWW::NOS::Open::Broadcast - Class representing client side broadcasts in the
-L<Open NOS|http://open.nos.nl/> REST API.
+WWW::NOS::Open::Broadcast - client side broadcasts in the Open NOS REST API.
 
 =head1 VERSION
 
-This document describes WWW::NOS::Open::Broadcast version 0.02.
+This document describes WWW::NOS::Open::Broadcast version 0.100.
 
 =head1 SYNOPSIS
 
@@ -158,12 +148,21 @@ strings.
 
 =head1 DEPENDENCIES
 
-L<DateTime|DateTime>
-L<Date::Parse|Date::Parse>
-L<URI|URI>
-L<Moose|Moose>
-L<Moose::Util::TypeConstraints|Moose::Util::TypeConstraints>
-L<namespace::autoclean|namespace::autoclean>
+=over 4
+
+=item * L<DateTime|DateTime>
+
+=item * L<Date::Parse|Date::Parse>
+
+=item * L<URI|URI>
+
+=item * L<Moose|Moose>
+
+=item * L<Moose::Util::TypeConstraints|Moose::Util::TypeConstraints>
+
+=item * L<namespace::autoclean|namespace::autoclean>
+
+=back
 
 =head1 INCOMPATIBILITIES
 
@@ -176,14 +175,14 @@ L<RT for rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-NOS-Open>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg  C<< <ipenburg@xs4all.nl> >>
+Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 by Roland van Ipenburg
+Copyright 2012 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.12.2 or,
+it under the same terms as Perl itself, either Perl version 5.14.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 =head1 DISCLAIMER OF WARRANTY
