@@ -1,32 +1,25 @@
-package WWW::NOS::Open::Result;    # -*- cperl; cperl-indent-level: 4 -*-
+package WWW::NOS::Open::Result 0.100;    # -*- cperl; cperl-indent-level: 4 -*-
 use strict;
 use warnings;
 
-# $Id: Result.pm 410 2011-01-13 20:39:07Z roland $
-# $Revision: 410 $
-# $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/candi/trunk/WWW-NOS-Open/lib/WWW/NOS/Open/Result.pm $
-# $Date: 2011-01-13 21:39:07 +0100 (Thu, 13 Jan 2011) $
-
 use utf8;
-use 5.006000;
-
-our $VERSION = '0.02';
+use 5.014000;
 
 use Moose qw/has/;
-use namespace::autoclean -also => qr/^__/sxm;
+use namespace::autoclean '-also' => qr/^__/sxm;
 
 has '_documents' => (
-    is       => 'ro',
-    isa      => 'ArrayRef[WWW::NOS::Open::Document]',
-    reader   => 'get_documents',
-    init_arg => 'documents',
+    'is'       => 'ro',
+    'isa'      => 'ArrayRef[WWW::NOS::Open::Document]',
+    'reader'   => 'get_documents',
+    'init_arg' => 'documents',
 );
 
 has '_related' => (
-    is       => 'ro',
-    isa      => 'ArrayRef[Str]',
-    reader   => 'get_related',
-    init_arg => 'related',
+    'is'       => 'ro',
+    'isa'      => 'ArrayRef[Str]',
+    'reader'   => 'get_related',
+    'init_arg' => 'related',
 );
 
 no Moose;
@@ -41,16 +34,13 @@ __END__
 
 =encoding utf8
 
-=for stopwords Roland van Ipenburg API NOS DateTime URI
-
 =head1 NAME
 
-WWW::NOS::Open::Result - Class representing a client side search result
-in the L<Open NOS|http://open.nos.nl/> REST API.
+WWW::NOS::Open::Result - client side search result in the Open NOS REST API.
 
 =head1 VERSION
 
-This document describes WWW::NOS::Open::Result version 0.02.
+This document describes WWW::NOS::Open::Result version 0.100.
 
 =head1 SYNOPSIS
 
@@ -78,9 +68,15 @@ array of strings.
 
 =head1 DEPENDENCIES
 
-L<Moose|Moose>
-L<WWW::NOS::Open::Document|WWW::NOS::Open::Document>
-L<namespace::autoclean|namespace::autoclean>
+=over 4
+
+=item * L<Moose|Moose>
+
+=item * L<WWW::NOS::Open::Document|WWW::NOS::Open::Document>
+
+=item * L<namespace::autoclean|namespace::autoclean>
+
+=back
 
 =head1 INCOMPATIBILITIES
 
@@ -93,14 +89,14 @@ L<RT for rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-NOS-Open>.
 
 =head1 AUTHOR
 
-Roland van Ipenburg  C<< <ipenburg@xs4all.nl> >>
+Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 by Roland van Ipenburg
+Copyright 2012 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.12.2 or,
+it under the same terms as Perl itself, either Perl version 5.14.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 =head1 DISCLAIMER OF WARRANTY
